@@ -530,8 +530,8 @@ longplot <- function(data,
     # my_binwidth <- (max(data[vars], na.rm=TRUE)-min(data[vars], na.rm=TRUE))/20
     write(paste0("#+ numeric_datetime, fig.width=12, fig.height=", long), file.path(dir, "brinton_outcomes", "longplot.R"), append=TRUE)  # gridExtra
     stripe <- c('scatter plot', 'scatter plot with trend line')
-    p001 <- pp_scatterplot(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 3/ncol, 'black', 'false')
-    p002 <- pp_scatterplot(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 3/ncol, 'black', 'true')
+    p001 <- pp_scatterplot(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 3/ncol, pp_color = 'black', pp_smooth = FALSE)
+    p002 <- pp_scatterplot(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 3/ncol, pp_color = 'black', pp_smooth = TRUE)
     add_plots("p00", 2)
     if (label == TRUE) {add_label("{date~num} OR {2date}", stripe)}
     stripe <- c('binned scatter plot', 'bw binned scatter plot', 'color binned scatter plot')
@@ -674,8 +674,9 @@ longplot <- function(data,
     if (label == TRUE) {add_label("2num", stripe)}
     stripe <- c('stepped area graph', 'bw stepped area graph', 'color stepped area graph')
     p151 <- pp_unfolded(data, colnames(data[vars][1]), colnames(data[vars][2]), 'black', pp_size = 3/ncol, pp_geom = 'bar')
-    p152 <- pp_unfolded(data, colnames(data[vars][1]), colnames(data[vars][2]), 'color', pp_size = 3/ncol, pp_geom = 'bar')
-    add_plots("p15", 2)
+    p152 <- pp_unfolded(data, colnames(data[vars][1]), colnames(data[vars][2]), 'bw', pp_size = 3/ncol, pp_geom = 'bar')
+    p153 <- pp_unfolded(data, colnames(data[vars][1]), colnames(data[vars][2]), 'color', pp_size = 3/ncol, pp_geom = 'bar')
+    add_plots("p15", 3)
     if (label == TRUE) {add_label("2num", stripe)}
     stripe <- c('blank', 'bw seq. heatmap', 'color seq. heatmap')
     p161 <- blank2(data, colnames(data[vars][1]), colnames(data[vars][2]))
@@ -713,7 +714,7 @@ longplot <- function(data,
     p221 <- pp_unf_yuxt(data, colnames(data[vars][1]), colnames(data[vars][2]), 'black', pp_size = 3/ncol, pp_geom = 'box')
     add_plots("p22", 1)
     if (label == TRUE) {add_label("2num", stripe)}
-    stripe <- c('histogram', 'bw histogram', 'color histogram')
+    stripe <- c('ecdf plot', 'point ecdf plot', 'stepped ecdf plot')
     p231 <- pp_unf_ecdf(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 1/ncol, pp_trans = 'line')
     p232 <- pp_unf_ecdf(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 1/ncol, pp_trans = 'point')
     p233 <- pp_unf_ecdf(data, colnames(data[vars][1]), colnames(data[vars][2]), pp_size = 1/ncol, pp_trans = 'step')
@@ -747,12 +748,12 @@ longplot <- function(data,
     add_plots("ofnum4", 3)
     if (label == TRUE) {add_label("fac-num", stripe)}
     stripe <- c('violin plot', 'filled violin plot')
-    ofnum21 <- pp_basicgraph(data, var1, var2, pp_size = 1/ncol, 'violin')
-    ofnum22 <- pp_basicgraph(data, var1, var2, pp_size = 1/ncol, 'violin filled')
+    ofnum21 <- pp_basicgraph(data, var2, var1, pp_size = 1/ncol, 'violin')
+    ofnum22 <- pp_basicgraph(data, var2, var1, pp_size = 1/ncol, 'violin filled')
     add_plots("ofnum2", 2)
     if (label == TRUE) {add_label("fac-num", stripe)}
     stripe <- c('box plot')
-    ofnum31 <- pp_basicgraph(data, var1, var2, pp_size = 1/ncol, 'box')
+    ofnum31 <- pp_basicgraph(data, var2, var1, pp_size = 1/ncol, 'box')
     add_plots("ofnum3", 1)
     if (label == TRUE) {add_label("fac-num", stripe)}
     write(paste0("#+ factor_numeric2, fig.width=12, fig.height=2"), file.path(dir, "brinton_outcomes", "longplot.R"), append=TRUE)  # gridExtra
@@ -778,8 +779,8 @@ longplot <- function(data,
                 'color filled density plot')
     ofnum71 <- pp_density2(data, var1, var2, 0.5, "line", "bw")
     ofnum72 <- pp_density2(data, var1, var2, 0.5, "line", "color")
-    ofnum73 <- pp_density2(data, var1, var2, 0.5, "area", "bw")
-    ofnum74 <- pp_density2(data, var1, var2, 0.5, "area", "color")
+    ofnum73 <- pp_density2(data, var2, var1, 0.5, "area", "bw")
+    ofnum74 <- pp_density2(data, var2, var1, 0.5, "area", pp_color="color")
     add_plots("ofnum7", 4)
     if (label == TRUE) {add_label("fac-num", stripe)}
     rmarkdown::render(file.path(dir, "brinton_outcomes", "longplot.R"),"html_document")
